function dot= CMG_Dynamics(delta,deldot,x,Td)                    % s/c Dynamics with CMG
global J Jinv m ref quad hcmg d2r r2d 

% State Variables (x)
% x(1-3)   = Body rates   (w)   (rad/sec)
% x(4-7)   = Quaternion 
% Inputs:
% Td(3)    = Disturbance Torque (ft-lb)
% delta(4) = Gimbal Deflections (rad)
% deldot(4)= Gimbal Rates (rad/sec)

dot= zeros(16,1);
w= x(1:3);  
h= [0 0 0]';

for i=1:4
    A(:,i)=     (-sin(delta(i))*ref(:,i) + cos(delta(i))*quad(:,i))*hcmg(i);
    h = h +      (cos(delta(i))*ref(:,i) + sin(delta(i))*quad(:,i))*hcmg(i);
    harray(:,i)= (cos(delta(i))*ref(:,i) + sin(delta(i))*quad(:,i))*hcmg(i);
end

hs = J*w + h;                                          % System Momentum
Tcmg = -A*deldot -cross(w,h);                          % CMG torque (body)
dot(1:3)= Jinv*(Tcmg - cross(w,J*w) +Td);              % Vehicle acceleration
dot(4:7)= 0.5*[0      w(3)  -w(2)   w(1);              % Quaternion Update
              -w(3)   0      w(1)   w(2);
               w(2)  -w(1)   0      w(3);
              -w(1)  -w(2)  -w(3)   0]*x(4:7);          
dot(8:10) = h;                                         % CMG Momentum in body
dot(11:13)= hs;                                        % System Momentum
dot(14:16)= Tcmg;                                      % CMG Torques
