function [M, ref, quad]= M4(beta);
% Calculates the SG-CMG reference directions
% That is, Gimbal directions, the Initial Momentum directions, 
% and the Initial Torque directions for a four Sided Pyramid Configuration
% beta is the angle of each side from the pyramid base (deg)
% [M, ref, quad]= M4(beta);

b=beta*pi/180;                    % Pyramid angle in radians
sb= sin(b); cb= cos(b);

M= [sb    0    -sb     0;         % x Gimbal Rotation Vectors (s1,s2,s3,s4)
    0     sb    0    -sb;         % y
    cb    cb    cb    cb];        % z

ref= [0   -1    0    1;           % x Initial Momentum Vectors (h1,h2,h3,h4)
      1    0   -1    0;           % y
      0    0    0    0];          % z
     
for i=1:4                         % Orthogonal Axes (Initial Torque direct)
    quad(:,i)= cross(M(:,i),ref(:,i));
end
