function dot= Max_Energy_ACS(qc,q,x,wb)                % Max-Energy Attitude Controller
global d2r r2d wlim mx alim ki kp

% State Variables (x)
% x(1-3)  = Position Integration
% x(4)    = Kay Integrator
% x(5)    = Kay Filter
%--------------------------------------------------------

taupos= kp/ki;                                           % PI Gains ratio
dot= zeros(14,1);                                        % 14 outputs
Qe= qerror(qc,q); qe= Qe(1:3);                           % Attitude Quaternion error
kay=x(5);
dot(1:3)= ki*qe - 1*kay*x(1:3)/taupos;                   % Position Integration
if kay>0.02; dot(1:3)=-x(1:3)*5.0; end                   % Integrator is off when kay=1 
wccc= x(1:3) + kp*qe;                                    % PI Control when kay=0
mwccc= sqrt(wccc'*wccc);                                 % Attitude Error Magnitude
mwb= sqrt(wb'*wb);                                       % Rate Error Magnitude

% Energy Limit -----------------------------------------
% Commands a rate as a function of attit error which is determined
% by a 3-dimensional parabolic line [rate=sqrt(2*alim*Attit_error)]
wcc = zeros(3,1); 

if (qe'*qe)==0; alim=0; wclim=[0;0;0];
else; 
    alim=1/sqrt((qe(1)/mx(1))^2 +(qe(2)/mx(2))^2 +(qe(3)/mx(3))^2);
    wclim= sqrt(2*qe.*qe*alim);
end

for i=1:3
    if abs(wccc(i))>=wclim(i) & sqrt(qe'*qe)>0.00001 & abs(wccc(i))>0
          wcc(i)= wccc(i)*wclim(i)/abs(wccc(i));
    else; wcc(i)= wccc(i); end
end

% Velocity Limit ---------------------------------------
wclim = wlim*qe/sqrt(qe'*qe);                            % Vel limit resolved about rot vector
if sqrt(wcc'*wcc)>wlim                                   % if cmd exceeds max rate
    wc = wclim;                                          % go at max rate
else                                                     % otherwise ....
    wc = wcc;                                            % whatever is commanded by energy limit
end
dot(6:8) = qe;                                           % Quaternion Error Output
dot(9:11)= wc;                                           % Rate Command

% Compute kay ------------------------------------------
% When the attit error is small turn the integrator on by kay=0
% The integrator helps maintain small attitude error,
% but you don't need it while maneuvering
% delmax = max(max(deldot,-deldot));
% dot(4) = (delmax-1)*8;

erinx= (mwb + mwccc)*1.0e+5;
dot(4) = (erinx-1)*70;
if x(4)>1; dot(4)= dot(4) + (1-x(4))*50; end
if x(4)<0; dot(4)= dot(4) - x(4)*50; end
kayin = max(0,min(1.0,x(4)));

dot(5) = (kayin-x(5))*18;
if dot(5)>0; dot(5)= dot(5)*18; end
dot(12:14)= [kayin; erinx; kayin];
