function dot= Steering(wcmd,wb,wc,t,delta)  
global J ref quad hcmg d2r r2d 
global Acc_Lim Rat_Lim kr Es Ps Fs
%
% State Variables (x)
% x(1-3)  = Jerk Limiter
% we(3)   = Vehicle rate error
% delta(4)= Gimbal angles

dot= zeros(11,1);                                         % 7 outputs
we= wc-wb;
h= [0 0 0]';                                             % CMG Momentum
for i=1:4
    A(:,i)=(-sin(delta(i))*ref(:,i) + cos(delta(i))*quad(:,i))*hcmg(i);
    h = h + (cos(delta(i))*ref(:,i) + sin(delta(i))*quad(:,i))*hcmg(i);
end
wdot= kr*we;                                             % rate error

% Variable Acceleration Limit
wdotlim=  sqrt(Acc_Lim*sqrt(we'*we));
wdotrate= sqrt(wdot'*wdot);
if wdotrate>wdotlim; wdot=wdot*wdotlim/wdotrate; end

% Fixed Rate Limit
wdotmag= sqrt(wdot'*wdot); dot(1)= wdotmag;
if wdotmag > Rat_Lim; wdot= wdot*Rat_Lim/wdotmag; end
hdot= J*wdot; dot(2)= sqrt(hdot'*hdot);                  % Control torque

% Singularity avoidance
dot(3)=det(A*A'); lamb= Ps/det(A*A');
E= [1                    Es*sin(Fs*t)        Es*cos(Fs*t+pi/2);
    Es*sin(Fs*t)         1                   Es*sin(Fs*t-pi/2);
    Es*cos(Fs*t+pi/2)    Es*sin(Fs*t-pi/2)          1];

pinverse= A'*inv(A*A' + lamb*E);
ddc=-pinverse*(hdot-cross(wb,h)); ddm=sqrt(ddc'*ddc);    % Delta dot command
if ddm>1.5, ddc= ddc*1.5/ddm; end
dot(4:7)= ddc;                                           % Delta dot command
dot(8:11)=-pinverse*(hdot); 