function xdot= SC_CMG_Gimbal(x,Tci,Td,wf)                 % s/c Dynamics with CMG
global J Jinv hcmg bet gam Jgi Jsi Joi

% State Variables (x)
% x(1:3)   = Body rates   (w)        (rad/sec)
% x(4:6)   = CMG Momentum body (h)   (ft-lb-sec)
% x(7:10)  = Gimbal rates (delt-dot) (rad/sec)
% x(11:14) = Gimbal angles (delta)   (rad)
% x(15:18) = Quaternion 
% Inputs:
% Tci(4)   = Gimbal Torques (ft-lb)
% Td(3)    = Disturbance Torque (ft-lb)
% wf(3)    = Flex Body Rate

xdot= zeros(31,1);
w =     x(1:3);                                             % Rigid-Body rates
wt=     w+wf;                                               % Total body rate
h =     x(4:6);                                             % CMG Momentum
deldot= x(7:10);                                            % Gimbal rates
delta = x(11:14);                                           % Gimbal Angles
qt=     x(15:18);                                           % Quaternion
[Pj,thd,phd,ddd]= Transforms(bet,gam,delta,w);

Tcmg=zeros(3,1); h2=Tcmg;
for i=1:4
    sd=sin(delta(i)); cd=cos(delta(i));
    Mj=[Tci(i); ...                                         % CMG Torque in CMG axis
        deldot(i)*((Jsi-Jgi)*(thd(i)*cd+phd(i)*sd) +hcmg(i)); ...
        deldot(i)* (Jgi-Joi)*(phd(i)*cd-thd(i)*sd)];
    Tcmg= Tcmg - Pj(:,:,i)*Mj;                              % Torque on Vehicle
%   h2= h2 + (cos(delta(i))*ref(:,i) + sin(delta(i))*quad(:,i))*hcmg(i);
end

Hs = J*w + h;                                               % System Momentum

xdot(1:3)= Jinv*(Tcmg -cross(w,J*w) +Td);                   % Vehicle acceleration
wdot=xdot(1:3);                                             % Vehicle Acceleration
xdot(4:6)=-Tcmg -cross(w,h);                                % H-dot
for i=1:4
    sd=sin(delta(i)); cd=cos(delta(i));
    xdot(6+i)= (Tci(i)-hcmg(i)*(thd(i)*sd-phd(i)*cd))/Jgi;  % Gimbal accelr delt-ddot
    xdot(10+i)= x(6+i);                                     % Gimbal rates  delta-dot
end

xdot(15:18)= 0.5*[0    wt(3)  -wt(2)  wt(1);                % Quaternion Update
              -wt(3)    0      wt(1)  wt(2);
               wt(2)  -wt(1)   0      wt(3);
              -wt(1)  -wt(2)  -wt(3)  0]*qt;    
xdot(19:21)= Hs;                                            % System Momentum Hs
xdot(22:24)= wt;                                            % Total Vehi rate
xdot(25:27)= Tcmg;                                          % CMG Torques on Vehi
xdot(28:31)= ddd;                                           % delta_dot (Inertial-Relativ)