function dot= MaxEn_ACS(x,qe,wb)                   
global Ix Iy Iz d2r r2d
global Tmax maxvel maxvl1
% PID Attitude Controller with Energy and Velocity Limits
% Energy Manager and Maximum Velocity Limit for Large Errors
% Linear PID Controller for Small Errors
% -------------------------------------------------------
% State Variables (x)
% x(1-3)  = Position Integration
% x(4)    = Ky Integrator
% x(5)    = Ky Filter
% Inputs:
% qe(3)    = Attitude Error
% wb(3)    = Vehicle Body rates
% Outputs:
% dot(6:8) = wc (veloc command)
% dot(9:11)= [ky,angle,qwm]
% -------------------------------------------------------
dot= zeros(11,1);                                    % 11 outputs
Jd= [Ix, Iy, Iz];                                    % Ixx, Iyy, Izz  (slug-ft^2)
tlim=[10.0, Tmax,Tmax];                              % Max Torques x,y,z
mx=tlim./Jd;                                         % Max accelerations
ki=0.08; kp=3.0; ki2=0.012; kp2=0.25;                 % PI Gains (0.04, 2.4), (0.012; 0.3)
a=asin(sqrt(qe'*qe)); angle=a*2*r2d;                 % Maneuver error angle
wbm=sqrt(wb'*wb)*r2d;                                % Rate Error magnitude
qwm= 0.2*(angle + wbm*10);                           % Comb: (attit plus rate) error magn

q1=qe(1); qq=qe(2:3);                                % Split [pitch,yaw] and [roll]
ky=(1.0-x(5));                                       % x(5)= (from 1 to 0)
dot(1) = ki2*q1 - (ky*ki2/kp2)*(x(1) +kp2*q1);       % Roll Position Integration
dot(2:3)= ki*qq - (ky*ki/kp)*(x(2:3) +kp*qq);        % Pitch/Yaw Position Integrat
wccc(1)  = kp2*q1 + x(1);                            % PI controller (x)
wccc(2:3)= kp*qq + x(2:3);                           % PI controller (y,z)
wcc = zeros(3,1); wc=wcc;                            % Initialize

% Energy Limit -----------------------------------------
if (qq'*qq)==0; alim=0; wclim=[0;0];
else;   alim=1/sqrt((qe(2)/mx(2))^2+(qe(3)/mx(3))^2); 
        wclim= sqrt(2*qq.*qq*alim); end

if q1==0; alim1=0; wclm1=0;
else;     alim1= abs(mx(1)/q1); wclm1= sqrt(2*q1*q1*alim1); end

for i=1:2                                                  % The 2 SG-CMGs
    if abs(wccc(i+1))>=wclim(i) & sqrt(qq'*qq)>0.00001 & abs(wccc(i+1))>0
           wcc(i+1)= wccc(i+1)*wclim(i)/abs(wccc(i+1));
    else;  wcc(i+1)= wccc(i+1); end
end

if abs(wccc(1))>=wclm1 & abs(q1)>0.00001 & abs(wccc(1))>0  % The RW
          wcc(1)= wccc(1)*wclm1/abs(wccc(1));
else;     wcc(1)= wccc(1); end

% Velocity Limit ---------------------------------------
if abs(wcc(1))>maxvl1; wc(1)=maxvl1*q1/abs(q1); else; wc(1)= wcc(1); end
if sqrt(wcc(2:3)'*wcc(2:3))>maxvel; wc([2:3],1)=maxvel*qq/sqrt(qq'*qq);
else; wc([2:3],1)=wcc([2:3],1); end
dot(6:8)= wc;

% Compute ky ------------------------------------------
del=0; if qwm<1; del=1; end
dot(4) = del*2;
if x(4)>1; dot(4)= dot(4) + (1-x(4))*4; end
if x(4)<0; dot(4)= dot(4) - x(4)*4; end
kyin = max(0,min(1.0,x(4)));
dot(5)= (kyin-x(5))*4;
dot(9:11)= [ky,angle,qwm]';