function xdot= SC_RW_2CMG_Dyn1(x,delta,deldot,Tw,Td)        
global m ref quad d2r r2d
global J Jinv Iw hcmg 
% xdot= SC_RW_2CMG_Dyn1(x,delta,deldot,Tw,Td)
% Tw(1) = Reaction Wheel Torque in spacrft x-axis, (ft-lb)
% Td(3) = Disturbance Torque
% delta(2) = CMG Gimbal Angles (rad)
% deldot(2)= CMG Gimbal Rates

% State Variables (x)
% x(1-3)  = Body rates   (w)   (rad/sec)
% x(4-7)  = Quaternion 
% x(8)    = RW Rate

xdot= zeros(17,1);
h= [0 0 0]';
w=  x(1:3);                                           % S/C Body rates (rad/sec)
qt= x(4:7);                                           % S/C Quaternion Attitude
wr= x(8);                                             % React Wheel rate (rad/sec)

% CMG Momentum (h)
for i=1:2
    A(:,i)= (-sin(delta(i))*ref(:,i) + cos(delta(i))*quad(:,i))*hcmg(i);
    h = h +  (cos(delta(i))*ref(:,i) + sin(delta(i))*quad(:,i))*hcmg(i);
end

hs= J*w + h + [1 0 0]'*Iw*wr;                         % System Momentum (hs)
Tcmg = -A*deldot -cross(w,h);                         % CMG Torques (body)
xdot(1:3)= Jinv*(Tcmg +[1 0 0]'*Tw -cross(w,J*w)+Td); % Vehicle acceleration
xdot(4:7)= 0.5*[0    w(3)  -w(2) w(1);                % Quaternion Update
             -w(3)   0     w(1) w(2);
              w(2) -w(1)   0    w(3);
             -w(1) -w(2)  -w(3) 0]*qt;          
xdot(8)=    -Tw/Iw;                                   % R-Wheel inert accelerat
xdot(9:11) = h + [1 0 0]'*Iw*wr;                      % CMG + RW Momentum 
xdot(12:14)= hs;                                      % System Momentum
xdot(15:17)= Tcmg +[1 0 0]'*Tw;                       % CMG + RW Torques on s/c
