function xdot= SC_RW_2CMG_Dyn2(x,Tci,Tw,Td,wf)        
global nc d2r r2d
global J Jinv Iw Jsi Jgi Joi hcmg 
%--------------------------------------------------------------
% State Variables (x)
% x(1-3)   = Body rates   (w)   (rad/sec)
% x(4-7)   = Quaternion 
% x(8:10)  = h (CMG momentum)
% x(11:13) = RW Momentum
% x(14:15) = deldot
% x(16:17) = delta
% Inputs:
% Tci(2)   = Gimbal Torques (ft-lb)
% Tw(1)    = Reaction Wheel Torque in spacrft x-axis, (ft-lb)
% Td(3)    = Disturbance Torque (ft-lb)
% wf(3)    = Flex rate only from FEM system
%--------------------------------------------------------------
xdot= zeros(30,1);
w=  x(1:3);                                                 % S/C Body rates (rad/sec)
qt= x(4:7);                                                 % S/C Quaternion Attitude
h = x(8:10);                                                % CMG Momentum
hrw= x(11:13);                                              % React Wheel Momentum (body)
deldot= x(14:15); delidot=deldot;                           % Gimbal Rates relatv to s/c
delta = x(16:17);                                           % Gimbal Angles (rad)

wt= w+wf;                                                   % Total body rate + flex
wr = hrw(1)/Iw;                                             % Reaction Wheel Rate (rad/sec)
Twi= [Tw, 0, 0]';                                           % Wheel Torque Vector (ft-lb)
hs = J*w + h + hrw;                                         % System Momentum (hs)
[Pj,thd,phd,ddd]= Transforms(delta*r2d,w);                  % Resolve s/c rates along (ref,quad,gimb) 

Tcmg=zeros(3,1);                                            % Calculate CMG Torque in Body
for i=1:nc
    sd=sin(delta(i)); cd=cos(delta(i));
    Mj= [Tci(i); ...                                        % CMG Torque in CMG axis
    deldot(i)*((Jsi-Jgi)*(thd(i)*cd+phd(i)*sd) +hcmg(i)); ...
    deldot(i)* (Jgi-Joi)*(phd(i)*cd-thd(i)*sd)];
    Tcmg= Tcmg - Pj(:,:,i)*Mj;                              % Torque on Vehicle
    delidot(i)= delidot(i) + ddd(i);                        % Delta_Inertial_dot (rad)
end

xdot(1:3)= Jinv*(Tcmg +Twi - cross(w,J*w) );                % Vehicle acceleration
xdot(4:7)= 0.5*[0     wt(3)  -wt(2)  wt(1);                 % Quaternion Update
             -wt(3)   0       wt(1)  wt(2);                 % includes flex)
              wt(2)  -wt(1)   0      wt(3);
             -wt(1)  -wt(2)  -wt(3)  0]* qt;          
xdot(8:10)= -Tcmg - cross(w,h);                             % Hcmg_dot
xdot(11:13)= -Twi - cross(w,hrw);                           % R-Wheel Momentum dot
for i=1:nc
    sd=sin(delta(i)); cd=cos(delta(i));
    xdot(13+i)= (Tci(i)-hcmg(i)* ...                        % Gimbal acceler delta-ddot
        (thd(i)*sd-phd(i)*cd))/Jgi;          
    xdot(15+i)= x(13+i);                                    % Gimbal rates  delta-dot
end

% Additional Outputs
xdot(18:20)= hs;                                            % System Momentum 
xdot(21:23)= wt;                                            % Total Vehi rate
xdot(24:26)= h + hrw;                                       % CMG + RW Momentum 
xdot(27:29)= Tcmg + Twi;                                    % CMG + RW Torques on s/c 
xdot(30)   = wr;                                            % Wheel Rate (rad/sec)