function out= Steering_RW_CMG(wb,wbc,delta,t,wr)           
global m ref quad wcmg d2r r2d
global J Jinv Ix Iy Iz Iw hcmg
global Alim Wclim

% Inputs:
% wb(3)   = Body rates
% wbc(3)  = Body rate commands
% delta(2)= Gimbal angles
% t       = time
% wr(1)   = R-wheel rate (z)

krc= 5.2; krw=2.2;                                  % CMG, RW rate gains 5.2, 2.5
out= zeros(7,1); h= [0 0 0]';                       % 6 outputs
we = wbc-wb;                                        % Rate error
wdot1= krw*we(1);   wdmg1=abs(wdot1);               % RW  Accelerat Command
wdot2= krc*we(2:3); wdotmag=sqrt(wdot2'*wdot2);     % CMG Accelerat Command

% Acceleration Limit
if wdmg1>0.008; wdot1= 0.008*wdot1/wdmg1; end       % Limit x accelerat 0.004 (rad/sec^2)
if wdotmag > Alim; wdot2= Alim*wdot2/wdotmag; end   % Limit y & z accelerat to (Alim)

for i=1:2
    A(:,i)=(-sin(delta(i))*ref(:,i) + cos(delta(i))*quad(:,i))*hcmg(i);
    h = h + (cos(delta(i))*ref(:,i) + sin(delta(i))*quad(:,i))*hcmg(i);
end

% Singularity Avoidance Logic
lamb= 1.0e6/det(A'*A);
E= [1                0.01*sin(0.2*t);
    0.01*sin(0.2*t)           1];
pinverse= inv(A'*A + lamb*E)*A';
hrw= [1 0 0]'*Iw*wr;                                % RW momentum
Hsys= J*wb + h + hrw;                               % System Momentum 
Hmcs= h+hrw;                                        % Comb MCS Momentum

hdot = J*[0;wdot2];                                 % Desired torque in y,z
deldot= -pinverse*(hdot+cross(wb,Hsys));            % Delta dot command
ddmag=sqrt(deldot'*deldot);                         % Gimbal rate magnitude
if ddmag>Wclim; deldot=Wclim*deldot/ddmag; end      % Limit Gimbal rate < Wclim
   
gyro= cross(wb,hrw);                                % Gyro torque resolved in the x axis
out(1)= Ix*wdot1 - gyro(1);                         % R-Wheel Torque command
out(2:3)= deldot;
out(4:6)= h;
out(7)= 1/lamb;