%% Initialize Orbital Parameters
global d2r r2d 
global nt Thr cg Jloc Jdir MEloc MEdir Kr Ts
global ang_acl att_deadband kledge rate_lim low_rate_lim
d2r= pi/180; r2d=180/pi; Ts=0.02;
[Af, Bf, Cf, Df]= flex_spacecraft_fem_s;

nt=12; Thr=2.2;                                           % Number of thrusters
wb0=[-0.0, -0.0, -0.0]*d2r;                               % Initial body rates
qt0=[0, 0, 0, 1];                                         % Initial quaternion
x_ini= [wb0, qt0];                                        % State Initialization
cg=[-176.84, -2.52, 7.44]'; 

% RCS Jet Thrust Directions
Jdir= zeros(3,nt); Jloc=Jdir;
Jdir(:, 1)= [0.01,  -0.92, +0.39]';                       % BR-Y+Z
Jdir(:, 2)= [0.01,  +0.92, +0.39]';                       % BL+Y+Z
Jdir(:, 3)= [-0.09, -0.84, -0.535]';                      % FR-Y-Z
Jdir(:, 4)= [-0.09, +0.84, -0.535]';                      % FL+Y-Z
Jdir(:, 5)= [-0.08, -0.72, +0.69]';                       % FR-Y+Z
Jdir(:, 6)= [-0.08, +0.72, +0.69]';                       % FL+Y+Z
Jdir(:, 7)= [-0.99,  0.0,  +0.12]';                       % FRAxi-X
Jdir(:, 8)= [-0.99,  0.0,  +0.12]';                       % FLAxi-X
Jdir(:, 9)= [0.0,  -0.62, -0.78]';                        % BR-Y-Z
Jdir(:,10)= [0.0,  +0.62, -0.78]';                        % BL+Y-Z
Jdir(:,11)= [1.0,   0.0,   0.0]';                         % BRAxi+X
Jdir(:,12)= [1.0,   0.0,   0.0]';                         % BLAxi+X
MEdir =     [1.0,   0.0,   0.0]';                         % Reboost Engine

% RCS Jet Thrust Locations
Jloc(:,1) = [-307.53,  37.04,  8.15]';                    % BR-Y+Z
Jloc(:,2) = [-307.53, -37.04,  8.15]';                    % BL+Y+Z
Jloc(:,3) = [-25.13,   19.8,   7.15]';                    % FR-Y-Z
Jloc(:,4) = [-25.13,  -19.8,   7.15]';                    % FL+Y-Z
Jloc(:,5) = [-17.0,    15.32,  1.51]';                    % FR-Y+Z
Jloc(:,6) = [-17.0,   -15.32,  1.51]';                    % FL+Y+Z
Jloc(:,7) = [-8.04,     2.0,  -4.0]';                     % FRAxi-X
Jloc(:,8) = [-8.04,    -2.0,  -4.0]';                     % FLAxi-X
Jloc(:,9) = [-302.3,   37.34,  8.59]';                    % BR-Y-Z
Jloc(:,10)= [-302.3,  -37.34,  8.59]';                    % BL+Y-Z
Jloc(:,11)= [-322.3,   21.14,  0.051]';                   % BRAxi+X
Jloc(:,12)= [-322.3,  -21.14,  0.051]';                   % BLAxi+X
MEloc =     [-322.6,   -3.7,  -1.66]';                    % Reboost Engine

% Phase Plane Logic (deg)
ang_acl     = [0.2, 0.26,  0.27];
att_deadband= [0.2,  0.2,  0.2];
kledge      = [1.2,  1.2,  1.2];
rate_lim    = [0.3,  0.3,  0.3];
low_rate_lim= [0.15, 0.15, 0.15];

% Param for Describ-Funct Analysis
Na_max=0.636/(att_deadband(1)*d2r);                  % Max Describing Function
Kr(1)= rate_lim(1) /(2*ang_acl(1));                  % attit + rate mixing gain
Kr(2)= rate_lim(2) /(2*ang_acl(2));
Kr(3)= rate_lim(3) /(2*ang_acl(3));
