function fp= Jet_Select_dot(eu,nt,Thr,Jloc,Jdir,Imax)
% fp= Jet_Select_dot(eu,nt,Thr,Jloc,Jdir,Imax)
% Compute the thrust force vector (fp)
% Inputs
% eu(3) : ACS error unit vector
% nt    : number of jets
% Thr   : Thrust in (lb)
% Jloc  : Jet Locations 
% Jdir  : Thrust directions
% Imax  : Max number of Thrusters to select
% J     : Vehicle MOI matrix (3x3)
% cg(3) : CG location
% Outputs
% fp(nt): Thrusts vector (nt)

global J IJ cg
if sqrt(eu'*eu)<0.9, fp=zeros(nt,1); return; end    % Direct must be unit vect

tm= Thr*ones(1,nt);
vt= zeros(3,nt); pf= zeros(nt,1); sf=pf;

% Select the most dominant jets from all of them
for i=1:nt
    ln= (Jloc(:,i) - cg)/12;                        % Moment arms
    vt(:,i)= tm(i)*cross(ln,Jdir(:,i));             % Moments Matrix using all jets
    pf(i) = dot(vt(:,i),eu);                        % Moment dotted with maneuv direct
end

f2=pf;
for i=1:(nt/2)
    [mf,sf(i)]=max(f2); f2(sf(i))=0;                % Identify the strongest half
end
pf= pf/pf(sf(1));                                   % Normlz relative to strongest

% Select Imax jets among the strongest
Isel=1;                                             % First, select the strongest
for i=1:Imax-1
    if pf(sf(i+1))>0.7; Isel=Isel+1; end            % Then, choose one more to Imax
end

fp= zeros(nt,1);                                    % Initially zero all jets
for i=1:nt
    for j=1:Isel
        if i==sf(j); fp(i)=Thr; end                 % Turn on the selected thruster force
    end
end
