%% Initialize Orbital Parameters
global d2r r2d J IJ cg Mv
global nt Thr Jloc Jdir MEloc MEdir Ts Ltnk
global ang_acl att_deadband kledge rate_lim low_rate_lim
d2r= pi/180; r2d=180/pi; Ts=0.02;

Atti0=[0, 0, 0]'*d2r;                                     % Initial Euler Angles wrt LVLH
Worb= 0.00116;                                            % Orbital rate
Mv= 202.05;                                               % Vehicle mass
nt=12; Thr=2.2;                                           % Number of thrusters
wb0=[-0.0, -0.0, -0.0]*d2r;                               % Initial body rates
qt0=[0, 0, 0, 1];                                         % Initial quaternion
x_ini= [wb0, qt0];                                        % State Initialization

J= [0.175972E+4,  0.16151e+3,  0.1187E+2;                 % Vehicle MOI matrix in (slug-ft^2).
    0.16151e+3,   1.30452E+4, -0.3103E+2;
    0.1187E+2,   -0.3103E+2,   1.410986E+4];
IJ= inv(J);
cg=[-176.84, -2.52, 7.44]'; 
Ltnk=[-235, 0,  0,]';  Ltnk=(Ltnk-cg)/12;                 % Tank Center Location
    
% RCS Jet Thrust Directions
Jdir= zeros(3,nt); Jloc=Jdir;
Jdir(:, 1)= [0.01,  -0.92, +0.39]';                       % BR-Y+Z
Jdir(:, 2)= [0.01,  +0.92, +0.39]';                       % BL+Y+Z
Jdir(:, 3)= [-0.09, -0.84, -0.535]';                      % FR-Y-Z
Jdir(:, 4)= [-0.09, +0.84, -0.535]';                      % FL+Y-Z
Jdir(:, 5)= [-0.08, -0.72, +0.69]';                       % FR-Y+Z
Jdir(:, 6)= [-0.08, +0.72, +0.69]';                       % FL+Y+Z
Jdir(:, 7)= [-0.99,  0.0,  +0.12]';                       % FRAxi-X
Jdir(:, 8)= [-0.99,  0.0,  +0.12]';                       % FLAxi-X
Jdir(:, 9)= [0.0,  -0.62, -0.78]';                        % BR-Y-Z
Jdir(:,10)= [0.0,  +0.62, -0.78]';                        % BL+Y-Z
Jdir(:,11)= [1.0,   0.0,   0.0]';                         % BRAxi+X
Jdir(:,12)= [1.0,   0.0,   0.0]';                         % BLAxi+X
MEdir =     [1.0,   0.0,   0.0]';                         % Reboost Engine

% RCS Jet Thrust Locations
Jloc(:,1) = [-307.53,  37.04,  8.15]';                    % BR-Y+Z
Jloc(:,2) = [-307.53, -37.04,  8.15]';                    % BL+Y+Z
Jloc(:,3) = [-25.13,   19.8,   7.15]';                    % FR-Y-Z
Jloc(:,4) = [-25.13,  -19.8,   7.15]';                    % FL+Y-Z
Jloc(:,5) = [-17.0,    15.32,  1.51]';                    % FR-Y+Z
Jloc(:,6) = [-17.0,   -15.32,  1.51]';                    % FL+Y+Z
Jloc(:,7) = [-8.04,     2.0,  -4.0]';                     % FRAxi-X
Jloc(:,8) = [-8.04,    -2.0,  -4.0]';                     % FLAxi-X
Jloc(:,9) = [-302.3,   37.34,  8.59]';                    % BR-Y-Z
Jloc(:,10)= [-302.3,  -37.34,  8.59]';                    % BL+Y-Z
Jloc(:,11)= [-322.3,   21.14,  0.051]';                   % BRAxi+X
Jloc(:,12)= [-322.3,  -21.14,  0.051]';                   % BLAxi+X
MEloc =     [-322.6,   -2.0,   6.0]';                     % Reboost Engine

% Phase Plane Logic (deg)
ang_acl     = [0.2,  0.26, 0.27];
att_deadband= [0.1,  0.1,  0.1];
kledge      = [1.2,  1.2,  1.2];
rate_lim    = [0.5,  0.5,  0.5];
low_rate_lim= [0.15, 0.15, 0.15];
u= [1  -1  -1]'; com_dir= u/sqrt(u'*u);                     % vehicle eigenaxis rotat command
