function [js,tko]= Jet_Select_3dof(wd)
% Inputs:
% wd(3)  : angular acceleration demand
% nt     : Number of Thrusters
%
% Outputs:
% js(nt) : Selected jets are set to (1), otherwise are (0)
% tko(nt): Thrusters time on
global nt AI3 A3 Th Ts Ts2
tko=zeros(3,1); pmin=500000;                                   % Start with a huge fuel usage ...
                                                               % number to minimize
% Select 3 jets js(1 to 3) that minimize fuel usage in demanded direction                                                               
% and calculate the corresponding "on-times" tko(1 to 3)
for i=1:nt
    jp(1)=i;
    for j=1:nt
        if j ~= jp(1)
            jp(2)=j;
            for k=1:nt
                if (k ~= jp(1) & k ~= jp(2))                   % if k NE to the other sel. two jets
                    jp(3)=k; A2=zeros(3);                      % give it a try as third jet
                    for i2=1:3, A2(:,i2)=A3(:,jp(i2)); end     % extrct coresp cols from accel matrix A3
                    A2I= inv(A2); tk=A2I*wd; pos=1;            % calculate "on times" for sel. jets
                    for i2=1:3                                 % Selected jets should produce ...
                        if tk(i2)<0, pos=-1; break; end;       % no negative times
                    end
                    lamb=A2I'*[1;1;1]; p=lamb'*wd;             % p is measure of fuel usage
                    if (pos>0 & p<pmin & p>0)                  % condition to accept ...
                        js(1)=i; js(2)=j; js(3)=k;             % a new jets combination 
                        tko=tk; pmin=p;                        % on times for sel. jets
                    end
                end
            end
        end
    end
end

% Normalize the "on times" between zero and 0.5 (sec)
tmx=max(tko);                                           % max on-time
if tmx<Ts, tko=zeros(3,1); js=zeros(3,1); return        % don't fire any
elseif tmx>Ts2, tko= tko*Ts2/tmx; end                   % too much demand, scale times down
for i=1:3; if tko(i)<Ts, tko(i)=0; end; end             % avoid too short on-times
