function [Isel,sf]= Jet_Select_rotat(eu,Imax)
% [Isel,sf]= Jet_Select_rotat(eu,Imax)
% Uses the dot-product method to select up to Imax jets that  
% produce a torque in direction (eu)
% Inputs
% eu(3)    : ACS error vector from Phase-Plane
% nt       : number of jets
% Thr      : Thrust in (lb)
% Lo_rcs   : Jet Locations 
% Di_rcs   : Thrust directions
% Imax     : Max number of Thrusters to select
% cg(3)    : CG location
% Outputs
% Isel     : Number of Selected Jets
% sf(i)    : Array of Selected Jet Numbers

global J IJ cg nt Lo_rcs Di_rcs Thr Th
if  abs(eu)==0,                                     % Direct must not be zero
    fp=zeros(nt,1); Isel=0; sf=0; mg=fp; return; 
end  

vt= zeros(3,nt); pf= zeros(nt,1); sf=pf;

% Select the most dominant jets from all of them
for i=1:nt
    ln= (Lo_rcs(:,i) - cg)/12;                      % Moment arms
    vt(:,i)= Thr(i)*cross(ln,Di_rcs(:,i));          % Moments Matrix using all jets
    pf(i) = dot(vt(:,i),eu);                        % Moment dotted with maneuv direct
end

f2=pf;
for i=1:(nt/2)
    [mf,sf(i)]=max(f2); f2(sf(i))=0;                % Identify the strongest half
end
pf= pf/pf(sf(1));                                   % Normlz relative to strongest

% Select Imax jets among the strongest
Isel=1; mg(1)=pf(sf(1));                            % First, select the strongest
for i=1:Imax-1
    if pf(sf(i+1))>0.0;   
        Isel=Isel+1;                                % Then, choose one more to Imax
        mg(Isel)= pf(sf(i+1));
    end          
end
sf= sf(1:Isel)';
