% Calls a Simulink model "DescFun_Sim.Mdl" which contains the non-linearity
% and computes its Describing Function
Init
EE=[0.001, 0.005, 0.008, 0.013, 0.02, 0.03,  ...
    0.05, 0.08, 0.14, 0.2, 0.3, 0.5, 0.8, 1.2, 1.6, 2.2, 4.0];     % Amplitudes
omeg=[0.2 0.72, 3.19, 5.84, 10];                                   % Frequencies
lne=length(EE); Nf=length(omeg); s=zeros(Nf,lne);

for j=1:Nf
    omg=omeg(j);
    for i=1:lne
        E=EE(i);
        sim('DescFun_Sim');
%        DF(i)=(1/sqrt(DF_real^2 + DF_imag^2));
        DF(i)=(DF_real + sqrt(-1)*DF_imag)/-sqrt(-1);
    end
    s(j,:)=DF;
end

figure(1)
surf(EE, omeg, 20*log10(abs(s)))
shading interp
ylabel('Frequency (rad/sec)')
xlabel('Amplitude')
zlabel('Descr-Func Gain')
title('Descr-Func. Amplitude vs Frequency and Input Amplitude')

figure(2)
surf(EE, omeg, imag(log(s.*(real(s)~=0&imag(s)~=0)+eps)))
shading interp
ylabel('Frequency (rad/sec)')
xlabel('Amplitude')
zlabel('Descr-Func Phase')
title('Descr-Func. Phase vs Frequency and Input Amplitude')

% Compute the -1/N locus
df_hys=s(1,:);                        % Just the first Frequency
df_hys_1oN=-1./df_hys;
df_real_1oN=real(df_hys_1oN);
df_imag_1oN=imag(df_hys_1oN);
df_magdb_1oN= 20*log10(abs(df_hys_1oN));
df_phasedeg_1oN= angle(df_hys_1oN)*57.295;

df_hys2=s(2,:);                        % Just the 2nd Frequency
df_hys_1oN2=-1./df_hys2;
df_real_1oN2=real(df_hys_1oN2);
df_imag_1oN2=imag(df_hys_1oN2);
df_magdb_1oN2= 20*log10(abs(df_hys_1oN2));
df_phasedeg_1oN2= angle(df_hys_1oN2)*57.295;

df_hys3=s(3,:);                        % Just the 3nd Frequency
df_hys_1oN3=-1./df_hys3;
df_real_1oN3=real(df_hys_1oN3);
df_imag_1oN3=imag(df_hys_1oN3);
df_magdb_1oN3= 20*log10(abs(df_hys_1oN3));
df_phasedeg_1oN3= angle(df_hys_1oN3)*57.295;

df_hys4=s(4,:);                        % Just the 3nd Frequency
df_hys_1oN4=-1./df_hys4;
df_real_1oN4=real(df_hys_1oN4);
df_imag_1oN4=imag(df_hys_1oN4);
df_magdb_1oN4= 20*log10(abs(df_hys_1oN4));
df_phasedeg_1oN4= angle(df_hys_1oN4)*57.295;

figure(4)
plot(df_phasedeg_1oN, df_magdb_1oN, 'b', ...
     df_phasedeg_1oN2,df_magdb_1oN2,'r', ...
     df_phasedeg_1oN3,df_magdb_1oN3,'m', ...
     df_phasedeg_1oN4,df_magdb_1oN4,'g');
title('The 1/N Locus');
xlabel('Phase (deg)');
ylabel('Magn (dB)'); grid on;

save df0 df_magdb_1oN  df_phasedeg_1oN
save df2 df_magdb_1oN2 df_phasedeg_1oN2
save df3 df_magdb_1oN3 df_phasedeg_1oN3
save df4 df_magdb_1oN4 df_phasedeg_1oN4