function xdot= RB_Dynamics(x,f,Feng,Ftank,Td)   
% Spacecraft Rigid Body Dynamics
% out= SV_Dynamics(x,f,Feng,Ftank,Td) 
% State Variables (x)
% x(1:3)  = Body rates   (wb)   (rad/sec)
% x(4:7)  = Quaternion
% f(1:nt) = RCS Forces in (lbf) (row vector)
% Feng    = Main Engine Thrust (lb)
% Ftank(3)= Forces at the Tank Center (lb)
% Td(3)   = Disturbance Torque (ft-lb)
global J IJ Mv Lo_rcs Di_rcs MEloc MEdir 
global d2r r2d axm sah cg nt Thr Ltnk 

xdot=zeros(16,1);                                 % Initialize
wb= x(1:3);                                       % body rates (rad/sec)
qt= x(4:7);                                       % attitude quaternion
ve= x(8:10);                                      % velocity

% Thruster Forces and Moments
mr= zeros(3,1); Frcs=mr; Ft=mr;
for i=1:nt 
    ma= (Lo_rcs(:,i)-cg)/12;                      % Jet moment arms (ft)
    mr= mr + f(i)*cross(ma,Di_rcs(:,i));          % Total RCS Moment (ft-lb)
    Ft= Ft + f(i)*Di_rcs(:,i);                    % Total Force (lb)
end
mr = mr - cross(Ftank,Ltnk);                      % Moment due to Sloash Forces

% Add Main Engine Force and Moment
ma= (MEloc-cg)/12;                                % M_Eng moment arm (ft)
mr= mr + Feng*cross(ma,MEdir);                    % Total RCS Moment (ft-lb)
Ft= Ft + Ftank + Feng*MEdir;                      % Add Slosh and MainEng Force 

Hsys= J*wb;                                       % System Momentum in body
wbd=IJ*(mr -cross(wb,Hsys) +Td);                  % Vehicle angular acceleration
xdot(1:3)= wbd;                                   % Vehicle angular acceleration
xdot(4:7)= 0.5*[0    wb(3) -wb(2) wb(1);          % Quaternion Rate Update
             -wb(3)  0      wb(1) wb(2);
              wb(2) -wb(1)  0     wb(3);
             -wb(1) -wb(2) -wb(3) 0]*qt;
xdot(8:10) = Ft/Mv - cross(axm,wbd);              % Lin acceler at Navb Node 2
xdot(11:13)= Ft/Mv - cross(sah,wbd);              % Lin acceleration at Node 4
xdot(14:16)= Ft/Mv - cross(Ltnk,wbd);             % Lin acceler at tank Node 7
