function out= Slosh_0g(x,Acc) 
% Zero-g Slosh Model  
% out= Slosh_0g(x,Acc)  
% Computes the Slosh Forces on the Tank as a function of 
% Vehicle acceleration at the Tank
%
% State Variables (x) 
% x(1:3)  = Xsd Slosh Mass Velocity wrt Tank 
% x(4:6)  = Xs Slosh Mass Position wrt Tank 
% Acc(3}  = Spacecraft Linear Accelerat at Tank
% Msl     = Slosh Mass (slug)
% Rsl     = Pendulum length (ft)
% Ltnk(3} = Location of the Tank Center
% Ts      = Sampling Period (sec)
global Msl Rsl

xdot=zeros(6,1);                                      % Initialize
Xsd= x(1:3);                                          % Velocity of Msl (Tank Relative)
Xs = x(4:6);                                          % Position of Msl (Tank Relative)

% Find the Axial direction u1
rs= sqrt(Xs'*Xs);                                     % Scalar Distance of Msl from center
if rs==0, rs=0.0001;                                  % Avoid Xs in the center of sphere
    e=rand(3,1); Xs=e*rs/sqrt(e'*e);
end
u1= Xs/rs;                                            % Unit vector from center to mass

% Find the Tangential direction u2 
vm= sqrt(Xsd'*Xsd);                                   % Veloc magnit relative to tank
if vm==0, vm=0.0001;                                  % Avoid Xsd being zero
    e=rand(3,1); Xsd=e*vm/sqrt(e'*e);
end
uv= Xsd/vm;                                           % Unit vector along veloc Xsd
u3= cross(u1,uv);                                     % Unit Vect Perpendic to u1 & uv
u2= cross(u3,u1);                                     % Unit Vect along vel, Tangent to surface

% Non-Linear Spring Deflection 
delta= rs - Rsl;                                      % Spring Deflection
if delta>0                                            % Stretched Spring
    Kspr=250*delta^2 + 100;                           % Non-Linear Spring 350 100
    Kfr= 0.2; Kd1=45.0;                               % Friction Coefficients
    Wsl= dot((Xsd/rs),u2);                            % Slosh Mass angular rate tangent tank surf
else                                                  % Free-Floating
    Kspr=0; Kfr=0; Kd1=0; Wsl=0; delta=0;             % Zero all External Forces
end

% Forces on Slosh Mass and Spacecraft 
Fd= Kfr*Wsl;                                          % Tangent Viscous Frict Force on Mass
Fst= Kspr*delta + Msl*(rs*Wsl^2) + dot(Kd1*Xsd,u1);   % Radial Centripet, Spring & Dampinq accel
Xsdd= - (Fst/Msl)*u1 - (Fd/Msl)*u2 - Acc;             % Slosh mass Acceler wrt tank center
Fv= Fst*u1 + Fd*u2;                                   % Force on the Spacecraft

% State Derivatives 
xdot(1:3)= Xsdd;                                      % Xs-dot-dot 
xdot(4:6)= Xsd;                                       % Xs-dot 
out=[xdot; u1;u2;Fv; delta;Wsl];                      % Size[6, 3,3,3, 1,1]= 17
